==> astsa_1.9.tar.gz: astsa/man/lag1.plot.Rd <==
\name{lag1.plot}
\alias{lag1.plot}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Lag Plot - one time series
%%  ~~function to do ... ~~
}
\description{Produces a grid of scatterplots of a series versus lagged values of the series.
%%  ~~ A concise (1-5 lines) description of what the function does. ~~
}
\usage{
lag1.plot(series, max.lag = 1, corr = TRUE, smooth = TRUE, col = gray(.1))
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{series}{the data
%%     ~~Describe \code{series} here~~
}
  \item{max.lag}{maximum lag
%%     ~~Describe \code{max.lag} here~~
}
  \item{corr}{if TRUE, shows the autocorrelation value in a legend
%%     ~~Describe \code{corr} here~~
}
  \item{smooth}{if TRUE, adds a lowess fit to each scatterplot
%%     ~~Describe \code{smooth} here~~
}
  \item{col}{color of points; default is \code{gray(.1)}
} 
}
%\details{
%%%  ~~ If necessary, more details than the description above ~~
%}
%\value{
%%%  ~Describe the value returned
%%%  If it is a LIST, use
%%%  \item{comp1 }{Description of 'comp1'}
%%%  \item{comp2 }{Description of 'comp2'}
%%% ...
%}
\references{\url{http://www.stat.pitt.edu/stoffer/tsa4/} and \url{http://www.stat.pitt.edu/stoffer/tsda/} 
%% ~put references to the literature/web site here ~
}
\author{D.S. Stoffer
%%  ~~who you are~~
}


%% ~Make other sections like Warning with \section{Warning }{....} ~

%\seealso{
%%% ~~objects to See Also as \code{\link{help}}, ~~~
%}
\examples{
lag1.plot(soi, 9, col=4)
}
\keyword{ ts }

==> astsa_1.10.tar.gz: astsa/man/lag1.plot.Rd <==
\name{lag1.plot}
\alias{lag1.plot}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Lag Plot - one time series
%%  ~~function to do ... ~~
}
\description{Produces a grid of scatterplots of a series versus lagged values of the series.
%%  ~~ A concise (1-5 lines) description of what the function does. ~~
}
\usage{
lag1.plot(series, max.lag = 1, corr = TRUE, smooth = TRUE, col = gray(.1), ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{series}{the data
%%     ~~Describe \code{series} here~~
}
  \item{max.lag}{maximum lag
%%     ~~Describe \code{max.lag} here~~
}
  \item{corr}{if TRUE, shows the autocorrelation value in a legend
%%     ~~Describe \code{corr} here~~
}
  \item{smooth}{if TRUE, adds a lowess fit to each scatterplot
%%     ~~Describe \code{smooth} here~~
}
  \item{col}{color of points; default is \code{gray(.1)}
}
  \item{...}{additional graphical arguments}
}
%\details{
%%%  ~~ If necessary, more details than the description above ~~
%}
%\value{
%%%  ~Describe the value returned
%%%  If it is a LIST, use
%%%  \item{comp1 }{Description of 'comp1'}
%%%  \item{comp2 }{Description of 'comp2'}
%%% ...
%}
\references{\url{http://www.stat.pitt.edu/stoffer/tsa4/} and \url{http://www.stat.pitt.edu/stoffer/tsda/} 
%% ~put references to the literature/web site here ~
}
\author{D.S. Stoffer
%%  ~~who you are~~
}


%% ~Make other sections like Warning with \section{Warning }{....} ~

%\seealso{
%%% ~~objects to See Also as \code{\link{help}}, ~~~
%}
\examples{
lag1.plot(soi, 9, col=4)
lag1.plot(soi, max.lag=4, pch=20, cex=1.5, col=rgb(0,.5,1,.5))
}
\seealso{\code{\link{lag2.plot}}}
\keyword{ ts }
